@@ -57,7 +57,9 @@ C_GetFunctionList (CK_FUNCTION_LIST_PTR_PTR list)
 	if (!list)
 		return CKR_ARGUMENTS_BAD;
 
+#if !GLIB_CHECK_VERSION(2,35,0)
 	g_type_init ();
+#endif
 
 	gkm_crypto_initialize ();
 
